#
# spec file for package libewf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

%define lname libewf3
Name:           libewf
Version:        20240506
Release:        1.5
Summary:        Library for the Expert Witness Compression Format (EWF)
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libewf
Source:         https://github.com/libyal/libewf/releases/download/%version/%name-experimental-%version.tar.gz
#Source2:        https://github.com/libyal/libewf/releases/download/%version/%name-experimental-%version.tar.gz.asc
Source3:        %name.keyring
Source20:       http://downloads.sf.net/libewf/mount_ewf-20090113.py
Source21:       Expert_Witness_Compression_Format_EWF.pdf
Source23:       Expert_Witness_Compression_Format_2_EWF2.pdf
Patch1:         remove_date_time_macros.patch
BuildRequires:  %python_module devel
BuildRequires:  %python_module setuptools
BuildRequires:  bison
BuildRequires:  c_compiler
BuildRequires:  flex
BuildRequires:  gettext-tools >= 0.18.1
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  timezone
BuildRequires:  pkgconfig(bzip2) >= 1.0
BuildRequires:  pkgconfig(fuse) >= 2.6
BuildRequires:  pkgconfig(libbfio) >= 20240414
BuildRequires:  pkgconfig(libcaes) >= 20240413
BuildRequires:  pkgconfig(libcdata) >= 20240414
BuildRequires:  pkgconfig(libcdatetime) >= 20240414
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libcfile) >= 20240414
BuildRequires:  pkgconfig(libclocale) >= 20240414
BuildRequires:  pkgconfig(libcnotify) >= 20240414
BuildRequires:  pkgconfig(libcpath) >= 20240414
BuildRequires:  pkgconfig(libcsplit) >= 20240414
BuildRequires:  pkgconfig(libcthreads) >= 20240413
BuildRequires:  pkgconfig(libfcache) >= 20240414
BuildRequires:  pkgconfig(libfdata) >= 20240415
BuildRequires:  pkgconfig(libfdatetime) >= 20240415
BuildRequires:  pkgconfig(libfguid) >= 20240415
BuildRequires:  pkgconfig(libfvalue) >= 20240415
BuildRequires:  pkgconfig(libhmac) >= 20240417
BuildRequires:  pkgconfig(libodraw) >= 20240505
BuildRequires:  pkgconfig(libsmdev) >= 20240505
BuildRequires:  pkgconfig(libsmraw) >= 20240506
BuildRequires:  pkgconfig(libuna) >= 20240414
BuildRequires:  pkgconfig(openssl) >= 1.0.0
BuildRequires:  pkgconfig(uuid) >= 2.20
BuildRequires:  pkgconfig(zlib) >= 1.2.5
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
libewf is a library for support of the Expert Witness Compression
Format (EWF). It supports both the SMART format (EWF-S01) and the
EnCase format (EWF-E01). libewf allows you to read and write media
information within the EWF files. libewf allows to read files created
by EnCase 1 to 6, linen and FTK Imager.

%package -n %lname
Summary:        Library to support the Expert Witness Compression Format
License:        LGPL-3.0-or-later
Group:          System/Libraries
Requires:       timezone

%description -n %lname
libewf is a library for support of the Expert Witness Compression
Format (EWF). It supports both the SMART format (EWF-S01) and the
EnCase format (EWF-E01). libewf allows you to read and write media
information within the EWF files. libewf allows to read files created
by EnCase 1 to 6, linen and FTK Imager.

%package tools
Summary:        Utilities for the Expert Witness Compression Format (EWF)
License:        LGPL-3.0-or-later
Group:          System/Filesystems
Requires:       fuse
Requires:       python3-fuse >= 0.2

%description tools
Several tools for reading and writing EWF files.
It contains tools to acquire, verify and export EWF files.

%package devel
Summary:        Development files for libewf, an Expert Witness Compression Format library
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
libewf is a library for support of the Expert Witness Compression
Format (EWF). It supports both the SMART format (EWF-S01) and the
EnCase format (EWF-E01). libewf allows you to read and write media
information within the EWF files. libewf allows to read files created
by EnCase 1 to 6, linen and FTK Imager.

This subpackage contains libraries and header files for developing
applications that want to make use of %name.

%prep
%autosetup -p1 -n libewf-%version
cp -av %_sourcedir/*.pdf .

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --disable-rpath \
	--enable-wide-character-type \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
echo "$python" >lastpython
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv "%_builddir/rt"/* "%buildroot/"
find "%buildroot" -type f -name "*.la" -delete -print
install -Dpm0755 %_sourcedir/mount*py "%buildroot/%_sbindir/mount.ewf"
ln -s mount.ewf "%buildroot%_sbindir/umount.ewf"

%check
export PYTHON="$(cat lastpython)"
# The testsuite has a symbol overload for malloc,
# and that no longer works when using version-script
make check || :

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING*
%_libdir/libewf.so.*

%files -n %name-tools
%_bindir/ewfacquire
%_bindir/ewfacquirestream
%_bindir/ewfexport
%_bindir/ewfinfo
%_bindir/ewfmount
%_bindir/ewfrecover
%_bindir/ewfverify
### experimental file ###
%_bindir/ewfdebug

%_mandir/man1/ewf*.1*
%_sbindir/*mount.ewf

%files -n %name-devel
%license COPYING*
%doc *.pdf
%_includedir/libewf.h
%_includedir/libewf/
%_libdir/libewf.so
%_libdir/pkgconfig/libewf.pc
%_mandir/man3/libewf.3*

%files %python_files
%license COPYING*
%python_sitearch/*.so

%changelog
* Mon May  6 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240506
  * No user-visible changes
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Thu Nov 23 2023 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (only needed when _service makes
  tarballs directly from git)
* Sun Nov 19 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231119
  * Allow UTF-16 stream unpaired surrogates in ltree
  * Changed ltree path segment separator
- Delete 20230324.diff (merged)
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Sun Mar 26 2023 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20230324
  * Adjust to changed libfdata API
- Add 20230324.diff
* Tue Feb 14 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230212
  * EWF2 support
  * ewfverify can auto-detect digest type
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Mon Oct 24 2022 Ludwig Nussel <lnussel@suse.de>
- UsrMerge (boo#1191067)
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Fri Jan 21 2022 Jan Engelhardt <jengelh@inai.de>
- Edit specfile to do multipython builds.
  (Reenables python2 on Leap 15)
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Drop python2 module build.
* Fri May 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot (a791283c)
  * No changelog was provided.
- Add system-libs.patch
* Sat Dec 12 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to libewf-20140811
  * address errors in retries in ewfacquire
  * changes to libmfdata
  * changes to ewfwrite
- change Requires python-fuse to python3-fuse
- requires libbfio v20201127 or newer
* Sun Jan 26 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to libewf-20140808
  * 2014 is the stable branch. 20140808 was released Dec 25, 2019
  * update libyal packages to Jan 2019 versions
  * Added deflate and adler32 fallback implementations
  * Removed dependency on libcstring and libcsystem
  * Added Python 3 support for pyewf
- add %%sosuffix variable and set it to 2
- update URL and Source fields to current web locations
- use separate libyal packages, not internal copies
* Fri Jan 17 2020 Matej Cepl <mcepl@suse.com>
- Switch on building of python3 bindings, and make building of
  python2 bindings conditional (default off).
* Fri Apr 19 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- Use the built in version of libcpath
  * libcpath has been updated and one of the functions renamed
  * until libewf is updated the internal version of libcpath must be used
* Sun Jan 14 2018 Greg.Freemyer@gmail.com
- fix a problem with the python to python2 rename
* Wed Oct 11 2017 Greg.Freemyer@gmail.com
- add skeleton python3 support - upstream doesn't have python 3 in the stable release
- rename python-libewf to python2-libewf to be compatible with python singlespec
- remove pyewf as it isn't versioned and isn't singlespec compatible
* Sat Jan 10 2015 Greg.Freemyer@gmail.com
- clean up buildrequires section
- remove %%if opensuse.  Not needed now that libyal is in security:forensics.
- begin to use newly released libyal packages from OBS
* Mon Aug 25 2014 Greg.Freemyer@gmail.com
- The latest update of libsmraw in factory is not building right in libewf.
  - Use internal version instead
- add a version number to Provides: pyewf
* Wed Aug 20 2014 Greg.Freemyer@gmail.com
- update to libewf-20140608
  * worked on integrating multi threaded ewfacquire changes
  * bug fix for utf16 header functions
  * bug fix in ewfmount regarding logical files date and time values
  * make pyewf_handle_open more strict to catch non-string objects
  without the check the code will segfault on non-string objects
  * bug fixes in empty block compression
  * bug fix in libewf_read_io_handle_read_chunk_data error tolerance
  code path
  * bug fix in recent process status changes
  * changed behavior of empty-block check
- review BuildRequires for new external packages
- use external packages where possible
- added to python sub-package section
  - Requires:       %%{lname} = %%{version"
  - Provides:       pyewf
- ran spec-cleaner
* Mon Feb  3 2014 varadgautam@gmail.com
- update to libewf-20140201
- remove nonexistent README.dll from %%doc
* Wed Jul 31 2013 Greg.Freemyer@gmail.com
- update to 0~20130416
  * changes to zlib.m4 for adler32 detection
- add Obsoletes/Provides pair for ewftools.  That was the old name of the tool package.
* Fri Apr  5 2013 jengelh@inai.de
- Cleanups: Set RPM group, license, summary and description
  metadata; remove unused %%py_requires; do not bloat shlib package
  with documentation
- Use system libraries instead of bundled ones where possible
- Name the tools package according to upstream's recommendation
- Drop unnecessary -fno-strict-aliasing
* Wed Apr  3 2013 Greg.Freemyer@gmail.com
- update to latest release 20130331
  * more sync with experimental version
  * improved error tolerance for issue 8
  * updated libsmdev to fix issue 13
- add 2 documentation files provided by upstream
- fix a illegal group setting
- update %%files sections to match sample specfile in source tree
- update Requires and BuildRequires to match sample specfile in source tree
* Fri Mar  8 2013 Greg.Freemyer@gmail.com
- ensure fuse-devel is installed during build so the ./configure will find it
- ewfmount fails in some circumstances without this
* Wed Feb 13 2013 hpj@urpla.net
- update to libewf-20130128
- more sync to closer match the experimental version
- updated pyewf doc strings
- updated examples
- fix for zero sized section corruption scenario
* Tue Dec 11 2012 Greg.Freemyer@gmail.com
- update to libewf-20121209
  removed memwatch and gettext
- change license back to LGPL-3.0+
- closes BNC# 778993
- create new sub-package python-libewf with python bindings
* Thu Sep  6 2012 Greg.Freemyer@gmail.com
- change license to GPL-3.0+ until upstream resolves LGPL-3.0+ status (BNC# 778993)
- run spec-cleaner
- make soname a define
- remove requires libewf from ewftools sub-package
* Wed Sep  5 2012 Greg.Freemyer@gmail.com
- upgrade to libewf-20120813
  * Bug fixes and multiple enhancements
  * soname update from 1 to 2
  * see ChangeLog
- remove pyver patch, now upstream
- add remove_date_time_macros.patch to keep builds consistent
- add zlib as requires as per sample specfile in tarball
- Add SLES build support
* Wed Feb  8 2012 saschpe@suse.de
- Spec file cleanup:
  * Provide sane versioning, this will break updates in the 'security'
    project now, but this is better than breaking Factory updates later.
  * Don't "rm -rf %%buildroot" in the %%install section
  * Use upstream tarballs
  * Cleanup BuildRequires
* Mon Feb  6 2012 cfarrell@suse.com
- license update: LGPL-3.0+
  No indication that LGPL-3.0 is the license (i.e. only). Looks like
  LGPL-3.0+
* Sun Sep  4 2011 toganm@opensuse.org
- Reworked spec based on fedora package
- TODO
  +enable disktype for requires
* Tue Sep 14 2010 toganm@opensuse.org
- Initial opensuse build service checkin
